@@ -79,11 +79,19 @@ MiaImage3d *load_vista_image(const char *filename)
 		break; 
 	default:
 		g_warning("Input type not supported");
+		return NULL; 
 	}
 	
-	VistaIOGetAttr( VistaIOImageAttrList(img), "voxel", NULL, VistaIOStringRepn, &voxel_size); 
-	if (sscanf(voxel_size, "%f %f %f", &sx, &sy, &sz) == 3) {
-		mia_image3d_set_scales(result, sx, sy, sz); 
+	if ( VistaIOGetAttr( VistaIOImageAttrList(img), "voxel", NULL, VistaIOStringRepn, &voxel_size) ==
+	     VistaIOAttrFound) {
+		if (sscanf(voxel_size, "%f %f %f", &sx, &sy, &sz) == 3) {
+			mia_image3d_set_scales(result, sx, sy, sz); 
+		}else{
+			g_warning("unable to interpret input file voxel size attribute'%s', assume (1,1,1)", 
+				  voxel_size);
+		}
+	}else{
+		g_warning("Input file has no voxel size attribute, assume (1,1,1)");
 	}
 
 
